summaryrefslogtreecommitdiff
path: root/src/components/smart_objects/include/smart_objects/errors.h
diff options
context:
space:
mode:
authorjacobkeeler <jacob.keeler@livioradio.com>2018-08-29 15:12:55 -0400
committerjacobkeeler <jacob.keeler@livioradio.com>2018-08-29 15:12:55 -0400
commit4746c58bf30b41f0a121a7b5dbc177aa2a28be02 (patch)
treee03d518826b79eba69e652e77a1da3d33a741f25 /src/components/smart_objects/include/smart_objects/errors.h
parent09e4e684708ad5ab2544c72745516e9fe481ba0b (diff)
downloadsdl_core-4746c58bf30b41f0a121a7b5dbc177aa2a28be02.tar.gz
Fix namespace case structure in projectfix/namespace_case
Diffstat (limited to 'src/components/smart_objects/include/smart_objects/errors.h')
-rw-r--r--src/components/smart_objects/include/smart_objects/errors.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/components/smart_objects/include/smart_objects/errors.h b/src/components/smart_objects/include/smart_objects/errors.h
index 5d22d2386e..8fc73be049 100644
--- a/src/components/smart_objects/include/smart_objects/errors.h
+++ b/src/components/smart_objects/include/smart_objects/errors.h
@@ -31,9 +31,9 @@
#ifndef SRC_COMPONENTS_SMART_OBJECTS_INCLUDE_SMART_OBJECTS_ERRORS_H_
#define SRC_COMPONENTS_SMART_OBJECTS_INCLUDE_SMART_OBJECTS_ERRORS_H_
-namespace NsSmartDeviceLink {
-namespace NsSmartObjects {
-namespace Errors {
+namespace ns_smart_device_link {
+namespace ns_smart_objects {
+namespace errors {
/**
* @brief Enumeration that provides information about SmartObject validation
*errors
@@ -64,8 +64,8 @@ enum eType {
**/
ERROR
};
-} // namespace Errors
-} // namespace NsSmartObjects
-} // namespace NsSmartDeviceLink
+} // namespace errors
+} // namespace ns_smart_objects
+} // namespace ns_smart_device_link
#endif // SRC_COMPONENTS_SMART_OBJECTS_INCLUDE_SMART_OBJECTS_ERRORS_H_